@@ -598,7 +598,8 @@ static int test_timeout_link_chain1(struct io_uring *ring)
 			}
 			break;
 		case 2:
-			if (cqe->res != -EALREADY) {
+			/* FASTPOLL kernels can cancel successfully */
+			if (cqe->res != -EALREADY && cqe->res != -ETIME) {
 				fprintf(stderr, "Req %llu got %d\n", cqe->user_data,
 						cqe->res);
 				goto err;
@@ -996,6 +997,9 @@ int main(int argc, char *argv[])
 	struct io_uring ring;
 	int ret;
 
+	if (argc > 1)
+		return 0;
+
 	ret = io_uring_queue_init(8, &ring, 0);
 	if (ret) {
 		printf("ring setup failed\n");
